# nr.io.graphviz

A simple utility for writing Graphviz files.

## API

*class* __`nr.io.graphviz.writer.GraphvizWriter(out: TextIO, indent: str = "\t")`__

*function* __`nr.io.graphviz.render.render(graphviz_code: str, format: str, algorithm: str = "dot") -> bytes`__

*function* __`nr.io.graphviz.render.render(graphviz_code: str, format: str, algorithm: str = "dot", output_file: Path) -> None`__
